@@ -1,12 +1,12 @@
 ################################################################################
-# "Working with dynamic models for agriculture"
+# Working with dynamic models for agriculture
 # R script for practical work
 # Daniel Wallach (INRA), David Makowski (INRA), James W. Jones (U.of Florida),
 # Francois Brun (ACTA)
-# version : 2010-08-09
+# version : 2013-06-09
 # Model described in the book, Appendix. Models used as illustrative examples: description and R code
 ################################ FUNCTIONS #####################################
-#' @title The weed update function
+#' @title The Weed model - calculate change for one year
 #' @description TOCOMPLETE
 #' @param d : weed density at seed emergence (plants/m2) - value for year
 #' @param S : seed production per m2 - value for year
@@ -19,8 +19,8 @@
 #' @return a vector with values of state variables for year+1
 #' @export
 weed.update=function(d, S, SSBa, DSBa, Soil, Crop, Herb, param) {
-# State variables
-# S : seed production (1/m2)
+# 4 state variables
+# S : seed production (seeds/m2)
 # d : weed density at seed emergence (plants/m2)
 # SSBa : surface seedbank after tillage (grains/m2)
 # DSBa : deep seedbank after tillage (grains/m2)
@@ -46,17 +46,17 @@ DSBa1=(1-chsi)*DSBb1+beta*SSBb1
 
 #d1=weed density at seed emergence (plants per m2) in year+1
 d1=param["delta.new"]*param["v"]*(1-param["phi"])*(1-beta)*S + param["delta.old"]*(SSBa1-S*param["v"]*(1-param["phi"])*(1-beta))
-#d1=weed density at maturity depending on herbicide  (plants per m2) in year+1
-D1=(1-param["mh"]*Herb)*(1-param["mc"])*d1
+#dm1=weed density at maturity depending on herbicide  (plants per m2) in year+1 (an auxillary variable). 
+dm1=(1-param["mh"]*Herb)*(1-param["mc"])*d1
 #S=seed production per m2 in year+1
-S1=Smax*D1/(1+alpha*D1)
-# Yield in year+1
-Yield1=max(0,param["Ymax"]*(1-(param["rmax"]*D1/(1+param["gamma"]*D1))))
+S1=Smax*dm1/(1+alpha*dm1)
+# Yield in year+1 (an auxillary variable).
+Yield1=max(0,param["Ymax"]*(1-(param["rmax"]*dm1/(1+param["gamma"]*dm1))))
 
 return(c(d1, S1, SSBa1, DSBa1, Yield1))
 }
 ################################################################################
-#' @title The weed model function
+#' @title The Weed model - calculate daily values over designated time period
 #' @description TOCOMPLETE
 #' @param param : vector of the 16 parameters
 #' @param weed.deci : decisions table for Soil, Crop et Herbicide 
@@ -67,7 +67,7 @@ weed.model=function(param, weed.deci) {
   duration=length(weed.deci$Soil)
 
   # Initialize variables
-  # 5 states variables, as 5 vectors initialized to NA
+  # 4 states variables, as vectors initialized to NA
   # Weed density (plants/m2)
   d=rep(NA,duration+1)
   # Seed production (grains/m2)
@@ -76,7 +76,8 @@ weed.model=function(param, weed.deci) {
   SSBa=rep(NA,duration+1)
   # Surface seed bank after tillage (grains/m2
   DSBa=rep(NA,duration+1)
-  # Yield (ton/ha)
+
+  # Yield (ton/ha), an auxillary variable. 
   Yield=rep(NA,duration+1)
 
   # Initialize state variables when sowing on day "sdate"
@@ -104,7 +105,7 @@ return(data.frame(year=0:duration,d=d,S=S,SSBa=SSBa,DSBa=DSBa,Yield=Yield))
 }
 
 ################################################################################
-#' @title Wrapping function to run an virtual experimental design for weed model
+#' @title Wrapper function to run the Weed model multiple times (for multiple sets of inputs)
 #' @param X : parameter matrix
 #' @param weed.deci : decisions table for Soil, Crop et Herbicide 
 #' @return matrix with Yield for year 3 for each parameter vector
@@ -116,7 +117,7 @@ weed.simule=function(X, weed.deci) {
 }
 
 ################################################################################
-#' @title Define parameter values of the weed model function
+#' @title Define parameter values of the Weed model
 #' @return matrix with parameter values (nominal, binf, bsup)
 #' @export
 weed.define.param = function()
@@ -157,4 +158,4 @@ param["bsup","beta.1"]=min(1,param["bsup","beta.1"])
 return(as.matrix(param))
 }
 
-# End file
\ No newline at end of file
+# End file
